@@ -46,7 +46,7 @@
 
 #include <R.h>
 #include <Rinternals.h>
-#include <Rdefines.h>
+/*#include <Rdefines.h>*/
 #include "xts.h"
 
 #ifndef MAX
